@@ -28,8 +28,6 @@
 #include <gtk/gtk.h>
 #include <NvCtrlAttributes.h>
 
-#include "glxinfo.h" /* xxx_abbrev functions */
-
 #include "glx_banner.h"
 #include "ctkglx.h"
 #include "ctkconfig.h"
@@ -38,6 +36,15 @@
 #include <GL/glx.h> /* GLX #defines */
 
 
+
+/* Prototypes */
+
+static void ctk_glx_probe_info(GtkWidget *widget,
+                               GtkObject *old_parent,
+                               gpointer data);
+
+
+
 /* Number of FBConfigs attributes reported in gui */
 #define NUM_FBCONFIG_ATTRIBS  30
 
@@ -66,16 +73,16 @@ static const char * __st_help =
   "st (Stereo buffer) - 'y' if the configuration has left and right color "
   "buffers that are rendered to in stereo.  '-' if this is not supported";
 static const char * __rs_help =
-  "rs (Red size) - Number of bits used for ammount of red per color. "
+  "rs (Red size) - Number of bits per color used for red. "
   "(Undefined for configurations that use color indexing.)";
 static const char * __gs_help =
-  "gs (Green size - Number of bits used for ammount of green per color. "
+  "gs (Green size - Number of bits per color used for green. "
   "(Undefined for configurations that use color indexing.)";
 static const char * __bs_help =
-  "bs (Blue size - Number of bits used for ammount of blue per color. "
+  "bs (Blue size - Number of bits per color used for blue. "
   "(Undefined for configurations that use color indexing.)";
 static const char * __as_help =
-  "as (Alpha size - Number of bits used for ammount of alpha per color. "
+  "as (Alpha size - Number of bits per color used for alpha. "
   "(Undefined for configurations that use color indexing.)";
 static const char * __aux_help =
   "aux (Auxillary buffers) - Number of available auxiliary color butters.";
@@ -84,17 +91,17 @@ static const char * __dpt_help =
 static const char * __stn_help =
   "stn (Stencil size) - Number of bits per element in the stencil buffer.";
 static const char * __acr_help =
-  "acr (Accumulator red size) - Number of bits used for ammount of red per "
-  "color in the accumulator buffer.";
+  "acr (Accumulator red size) - Number of bits per color used for red "
+  "in the accumulator buffer.";
 static const char * __acg_help =
-  "acg (Accumulator green size) - Number of bits used for ammount of green "
-  "per color in the accumulator buffer.";
+  "acg (Accumulator green size) - Number of bits per color used for green "
+  "in the accumulator buffer.";
 static const char * __acb_help =
-  "acb (Accumulator blue size) - Number of bits used for ammount of blue per "
-  "color in the accumulator buffer.";
+  "acb (Accumulator blue size) - Number of bits per color used for blue "
+  "in the accumulator buffer.";
 static const char * __aca_help =
-  "aca (Accumulator alpha size) - Number of bits used for ammount of alpha "
-  "per color in the accumulator buffer.";
+  "aca (Accumulator alpha size) - Number of bits per color used for alpha "
+  "in the accumulator buffer.";
 static const char * __ms_help =
   "ms (Multisample samples) - Number of samples per multisample.";
 static const char * __mb_help =
@@ -201,7 +208,7 @@ GtkWidget* ctk_glx_new(NvCtrlAttributeHandle *handle,
     GtkWidget *image;
     GtkWidget *frame;
     GtkWidget *hseparator;
-    GtkWidget *hbox;
+    GtkWidget *hbox, *hbox2;
     GtkWidget *vbox, *vbox2;
     GtkWidget *alignment;
     GtkWidget *table;
@@ -279,7 +286,7 @@ GtkWidget* ctk_glx_new(NvCtrlAttributeHandle *handle,
     /* Determine if GLX is supported */
     ret = NvCtrlGetStringAttribute(ctk_glx->handle,
                                    NV_CTRL_STRING_GLX_SERVER_VENDOR,
-                                   &glx_info_str);
+                                   &glx_info_str );
     free(glx_info_str);
     if ( ret != NvCtrlSuccess ) {
         goto fail_glx_not_supported;
@@ -461,6 +468,12 @@ GtkWidget* ctk_glx_new(NvCtrlAttributeHandle *handle,
 
     gtk_widget_show_all(GTK_WIDGET(object));
 
+    /* Set to probe for GLX info when widget is swapped in */
+    ctk_glx->probe_handler_id =
+        g_signal_connect(G_OBJECT(ctk_glx), "parent-set",
+                         G_CALLBACK(ctk_glx_probe_info),
+                         (gpointer) ctk_glx);
+
     return GTK_WIDGET(object);
 
 
@@ -490,9 +503,11 @@ GtkWidget* ctk_glx_new(NvCtrlAttributeHandle *handle,
 /* Probes for GLX information and sets up the results
  * in the GLX widget.
  */
-void ctk_glx_probe_info(GtkWidget *widget)
+static void ctk_glx_probe_info(GtkWidget *widget, 
+                               GtkObject *old_parent,
+                               gpointer data)
 {
-    CtkGLX *ctk_glx = CTK_GLX(widget);
+    CtkGLX *ctk_glx = (CtkGLX *) data;
 
     ReturnStatus ret;
 
@@ -517,15 +532,18 @@ void ctk_glx_probe_info(GtkWidget *widget)
     GtkWidget *table;
 
 
-    /* Make sure the widget was initialized and that glx information
-     * has not yet been initialized.
-     */
-    if ( !ctk_glx || !ctk_glx->glxinfo_vpane ||
-         ctk_glx->glxinfo_initialized ) {
+    /* Make sure the widget was initialized */
+    if ( !ctk_glx || !ctk_glx->glxinfo_vpane || !ctk_glx->probe_handler_id ) {
         return;
     }
 
 
+    /* Disconnect the handler */
+    g_signal_handler_disconnect(G_OBJECT(ctk_glx),
+                                ctk_glx->probe_handler_id);
+    ctk_glx->probe_handler_id = 0;
+
+
     /* Get GLX information */
     ret = NvCtrlGetStringAttribute(ctk_glx->handle,
                                    NV_CTRL_STRING_GLX_DIRECT_RENDERING,
@@ -700,7 +718,7 @@ void ctk_glx_probe_info(GtkWidget *widget)
     /* Show the information */
     gtk_widget_show_all(GTK_WIDGET(ctk_glx));
 
-    ctk_glx->glxinfo_initialized = True;
+
 
     /* Fall through */
  done:
